@@ -1,7 +1,7 @@
 import sys
 from Queue import Queue
 
-from circus.util import import_module
+from circus.util import import_module, resolve_name
 
 
 class QueueStream(Queue):
@@ -41,6 +41,29 @@ class StdoutStream(object):
         pass
 
 
+def get_stream(conf):
+    if not conf:
+        return conf
+
+    # we can have 'stream' or 'class' or 'filename'
+    if 'filename' in conf:
+        inst = FileStream(**conf)
+    elif 'stream' in conf:
+        inst = conf['stream']
+    elif 'class' in conf:
+        class_name = conf.pop('class')
+        if not "." in class_name:
+            class_name = "circus.stream.%s" % class_name
+        inst = resolve_name(class_name)(**conf)
+    else:
+        raise ValueError("stream configuration invalid")
+
+    # default refresh_time
+    refresh_time = float(conf.get('refresh_time', 0.3))
+
+    return {'stream': inst, 'refresh_time': refresh_time}
+
+
 def get_pipe_redirector(redirect, backend='thread', extra_info=None,
         buffer=1024):
     """Redirects data received in pipes to the redirect callable.
