@@ -24,4 +24,7 @@ class Redirector(BaseRedirector, Thread):
         if not self.running:
             return
         self.running = False
-        self.join()
+        try:
+            self.join()
+        except KeyboardInterrupt:
+            pass
