@@ -1,13 +1,14 @@
 import unittest
 import os
 from circus.config import get_config
-
+from circus.watcher import Watcher
 
 HERE = os.path.join(os.path.dirname(__file__))
 
 _CONF = {
     'issue137': os.path.join(HERE, 'issue137.ini'),
     'include': os.path.join(HERE, 'include.ini'),
+    'issue210': os.path.join(HERE, 'issue210.ini'),
 }
 
 
@@ -22,3 +23,8 @@ class TestConfig(unittest.TestCase):
         conf = get_config(_CONF['include'])
         watchers = conf['watchers']
         self.assertEquals(len(watchers), 4)
+
+    def test_watcher_graceful_timeout(self):
+        conf = get_config(_CONF['issue210'])
+        watcher = Watcher.load_from_config(conf['watchers'][0])
+        watcher.stop()
