@@ -79,6 +79,16 @@ class TestWatcher(TestCircus):
         self.assertTrue(self.stream.qsize() > 1)
 
 
+class TestWatcherFromConfiguration(TestCircus):
+
+    def test_env_from_string(self):
+        config = {'name': 'foobar',
+                  'cmd': 'foobar',
+                  'env': 'coconuts=migrate'}
+        watcher = Watcher.load_from_config(config)
+        self.assertEquals(watcher.env, {'coconuts': 'migrate'})
+
+
 class TestWatcherInitialization(TestCircus):
 
     def test_copy_env(self):
