@@ -41,11 +41,13 @@ if GEVENT:
             # let's open the web app
             res = self.app.get('/')
 
+            if res.status_code == 302:
+                res = res.follow()
+
             # we have a form to connect to the current app
             res = res.form.submit()
 
             # that should be a 302, redirecting to the connected index
             # let's follow it
             res = res.follow()
-
             self.assertTrue('tcp://127.0.0.1:5557' in res.body)
