@@ -1,3 +1,4 @@
+import copy
 import errno
 import os
 import signal
@@ -10,6 +11,7 @@ from circus.process import Process, DEAD_OR_ZOMBIE, UNEXISTING
 from circus import logger
 from circus import util
 from circus.stream import get_pipe_redirector, get_stream
+from circus.util import parse_env
 
 
 class Watcher(object):
@@ -129,13 +131,13 @@ class Watcher(object):
         self.args = args
         self._process_counter = 0
         self.stopped = stopped
-        self.graceful_timeout = graceful_timeout
+        self.graceful_timeout = float(graceful_timeout)
         self.prereload_fn = prereload_fn
         self.executable = None
         self.stream_backend = stream_backend
         self.priority = priority
-        self.stdout_stream_conf = stdout_stream
-        self.stderr_stream_conf = stderr_stream
+        self.stdout_stream_conf = copy.copy(stdout_stream)
+        self.stderr_stream_conf = copy.copy(stderr_stream)
         self.stdout_stream = get_stream(self.stdout_stream_conf)
         self.stderr_stream = get_stream(self.stderr_stream_conf)
         self.stdout_redirector = self.stderr_redirector = None
@@ -163,6 +165,7 @@ class Watcher(object):
         self.shell = shell
         self.uid = uid
         self.gid = gid
+
         if self.copy_env:
             self.env = os.environ.copy()
             if env is not None:
@@ -179,7 +182,6 @@ class Watcher(object):
             if (self.stdout_redirector is not None and
                 self.stdout_redirector.running):
                 self.stdout_redirector.kill()
-
             self.stdout_redirector = get_pipe_redirector(self.stdout_stream,
                     backend=self.stream_backend)
         else:
@@ -197,6 +199,8 @@ class Watcher(object):
 
     @classmethod
     def load_from_config(cls, config):
+        if 'env' in config:
+            config['env'] = parse_env(config['env'])
         return cls(name=config.pop('name'), cmd=config.pop('cmd'), **config)
 
     @util.debuglog
@@ -380,9 +384,17 @@ class Watcher(object):
             self.stderr_redirector.remove_redirection('stderr', process)
 
         try:
+            # sending the same signal to all the children
+            for child_pid in process.children():
+                process.send_signal_child(child_pid, sig)
+                self.notify_event("kill", {"process_pid": child_pid,
+                                  "time": time.time()})
+
+            # now sending the signal to the process itself
             self.send_signal(process.pid, sig)
             self.notify_event("kill", {"process_pid": process.pid,
                                    "time": time.time()})
+
         except NoSuchProcess:
             # already dead !
             return
@@ -471,7 +483,10 @@ class Watcher(object):
 
         while self.get_active_processes() and time.time() < limit:
             self.kill_processes(signal.SIGTERM)
-            time.sleep(0.1)
+            try:
+                time.sleep(0.1)
+            except KeyboardInterrupt:
+                pass
             self.reap_processes()
 
         self.kill_processes(signal.SIGKILL)
